Report

Struct Report 

pub struct Report<T> { /* private fields */ }
Error report that wraps a typed context with an optional source chain.

Implementations

Source

impl<T: StdError + Send + Sync + 'static> Report<T>

pub fn new(context: T) -> Self

Create a report from the given error context with no source.

pub fn current_context(&self) -> &T

The typed context stored in this report.

pub fn change_context<U: StdError + Send + Sync + 'static>( self, new_context: U, ) -> Report<U>

Wrap this report as the source of a new context.

pub fn attach(self, key: impl Into<String>, value: impl Display) -> Self

Add a key-value pair of additional context.

pub fn attach_path(self, value: impl AsRef<Path>) -> Self

Add a path as additional context under the key "path".

pub fn attach_with<D: Display>( self, key: impl Into<String>, value: impl FnOnce() -> D, ) -> Self

Add a key-value pair of additional context with a lazily evaluated value.