pub struct Report<T> { /* private fields */ }Expand description
Error report that wraps a typed context with an optional source chain.
Implementations
Sourceimpl<T: StdError + Send + Sync + 'static> Report<T>
impl<T: StdError + Send + Sync + 'static> Report<T>
Sourcepub fn current_context(&self) -> &T
pub fn current_context(&self) -> &T
The typed context stored in this report.
Sourcepub fn change_context<U: StdError + Send + Sync + 'static>(
self,
new_context: U,
) -> Report<U>
pub fn change_context<U: StdError + Send + Sync + 'static>( self, new_context: U, ) -> Report<U>
Wrap this report as the source of a new context.
Sourcepub fn attach(self, key: impl Into<String>, value: impl Display) -> Self
pub fn attach(self, key: impl Into<String>, value: impl Display) -> Self
Add a key-value pair of additional context.
Sourcepub fn attach_path(self, value: impl AsRef<Path>) -> Self
pub fn attach_path(self, value: impl AsRef<Path>) -> Self
Add a path as additional context under the key "path".