pub struct StructuredError { /* private fields */ }Expand description
Type-erased error with chained sources, attachments, and diagnostic rendering.
Implementations
Sourceimpl StructuredError
impl StructuredError
Sourcepub fn new<T: StdError + Send + Sync + 'static>(context: T) -> Self
pub fn new<T: StdError + Send + Sync + 'static>(context: T) -> Self
Create from any error, capturing its diagnostic code before type erasure.
Sourcepub fn change_context<T: StdError + Send + Sync + 'static>(
self,
new_context: T,
) -> StructuredError
pub fn change_context<T: StdError + Send + Sync + 'static>( self, new_context: T, ) -> StructuredError
Wrap this error as the source of a new context.
Sourcepub fn current_context(&self) -> &(dyn StdError + Send + Sync + 'static)
pub fn current_context(&self) -> &(dyn StdError + Send + Sync + 'static)
Get the current context.